{
  # config,
  diskoConfigurations,
  pkgs,
  hardware,
  ...
}:
{
  system.stateVersion = "24.11";
  networking = {
    hostName = "dragon";
    wifi.enable = true;
  };
  hardware.bluetooth.enable = true;
  boot = {
    kernelPackages = pkgs.linuxPackages_latest;
    loader = {
      efi.canTouchEfiVariables = true;
      systemd-boot.enable = true;
    };
  };
  imports = with hardware; [
    (diskoConfigurations.unencrypted { disk = "/dev/nvme0n1"; })
    common-cpu-amd
    common-gpu-amd
    common-pc-ssd
  ];

  lyte.desktop.enable = true;
  home-manager.users.daniel = {
    lyte = {
      useOutOfStoreSymlinks.enable = true;
      shell = {
        enable = true;
        learn-jujutsu-not-git.enable = true;
      };
      desktop.enable = true;
    };
  };

  programs.steam.enable = true;
  jovian = {
    decky-loader = {
      enable = true;
    };
    steam = {
      autoStart = true;
      updater = {
        splash = "jovian";
      };
    };
    hardware = {
      has.amd.gpu = true;
    };
    devices = {
      steamdeck = {
        enable = true;
        autoUpdate = true;
        # enableGyroDsuService = true;
      };
    };
  };
}
